@@ -776,7 +776,7 @@ class TgWrap():
             substacks = []
             for ss, substack in manifest['sub_stacks'].items():
                 # get the base directory of the sub stack so that we can ignore it when deploying the regular modules
-                substacks.append(substack['source_path'].split(os.path.sep)[0])
+                substacks.append(substack['source'].split(os.path.sep)[0])
 
             deploy_actions = {}
             for key, value in manifest['deploy'].items():
@@ -786,32 +786,37 @@ class TgWrap():
                     self.printer.verbose(f'Found deployment step: {key}')
 
                     source_path = os.path.join(source_dir, value['source_stage'])
-                    source_modules = [
-                        entry for entry in os.listdir(source_path) if os.path.isdir(os.path.join(source_path, entry))
-                        ]
+                    source_modules = {
+                        entry:{} for entry in os.listdir(source_path) if os.path.isdir(os.path.join(source_path, entry))
+                    }
                     self.printer.verbose(f'Found modules: {source_modules}')
 
-                    for module in source_modules:
-                        if module in value['exclude_modules'] or module in substacks:
-                            self.printer.verbose(f'Exclude module {module}')
-                        elif module in value['include_modules'] or len(value['include_modules']) == 0:
+                    include_modules = value['include_modules'] if len(value['include_modules']) > 0 else source_modules
+                    self.printer.verbose(f'Include modules: {include_modules}')
+
+                    for module, module_details in include_modules.items():
+                        source_module = module_details.get('source', module)
+                        target_module = module_details.get('target', module)
+                        if source_module in value['exclude_modules'] or source_module in substacks:
+                            self.printer.verbose(f'Exclude module {source_module}')
+                        else:
                             deploy_actions[module] = {
-                                "source": os.path.join(source_path, module, ''),
-                                "target": os.path.join(target_dir, module, ''),
+                                "source": os.path.join(source_path, source_module, ''),
+                                "target": os.path.join(target_dir, target_module, ''),
                             }
 
                     for ss, substack in manifest['sub_stacks'].items():
                         self.printer.verbose(f'Found substack : {ss}')
 
                         source_path = os.path.join(
-                            source_dir, value['source_stage'], substack['source_path'], ''
+                            source_dir, value['source_stage'], substack['source'], ''
                             )
                         target_path = os.path.join(
-                            target_dir, substack['target_path'], ''
+                            target_dir, substack['target'], ''
                             )
 
                         if os.path.exists(source_path):
-                            deploy_actions[f'substack -> {substack["target_path"]}'] = {
+                            deploy_actions[f'substack -> {substack["target"]}'] = {
                                 "source": source_path,
                                 "target": target_path,
                             }
